<?php
/*
Plugin Name: wp-recent-links
Version: 2.08
Plugin URI: http://rebelpixel.com/projects/wp-recent-links/
Description: A linklog plugin for WordPress, allowing you to have your own blog of links without the need for another wp-powered weblog or (gasp!) another weblog software. More information at the <a href="http://rebelpixel.com/projects/wp-recent-links/">project's page</a>.
Author: Markku Seguerra
Author URI: http://rebelpixel.com/
*/

$rp_recentlinks_title = '';
$rp_recentlinks_vars = '';
$rp_recentlinks_use_cqs = true;
$rp_recentlinks_version = 2.08;
/* =========================================================================
                                                    ++++++++++++++++++++++++
                                                    ++  rp_recentlinks()  ++
                                                    ++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the most recent links added to your linklog.

$limit
    The number of links to display.
    Defaults to 12.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or False.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 16:57:11
function rp_recentlinks($limit = 12,
                        $use_permalink = false,
                        $permalink_beginning = true,
                        $permalink_icon = '#',
                        $inline_caption = false,
                        $date_append = 'F j',
                        $before = '<li>',
                        $after = '</li>',
                        $between = "\n")
{
    global $table_prefix, $wpdb;

    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('gmt_offset');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }

    $now = gmdate('Y-m-d H:i:s',(time() + ($time_difference * 3600)));
    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' ORDER BY date_added DESC $limit";

    $links = $wpdb->get_results($sql);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }

            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&amp;')  &&  !strpos($link->link_url, '&#038;')  ) {
                $link->link_url = str_replace('&', '&amp;', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&amp;m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }

                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }


            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}












/* =========================================================================
                                       +++++++++++++++++++++++++++++++++++++
                                       ++  rp_recentlinks_archives_url()  ++
                                       +++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the archives page for the
recent links plugin.

========================================================================= */
function rp_recentlinks_archives_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/';
    } else {
        echo $siteurl.'/wp-recent-links.php';
    }
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_rss2_url()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the RSS 2 feed for the
recent links plugin.

========================================================================= */
// 2004-05-18 17:07:04
function rp_recentlinks_rss2_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/feed/';
    } else {
        echo $siteurl.'/wp-recent-links-rss2.php';
    }
}









/* =========================================================================
                                              ++++++++++++++++++++++++++++++
                                              ++  rp_recentlinks_month()  ++
                                              ++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the links for the given month.

$limit
    The number of links to display.
    Defaults to 12.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or Flase.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22
$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 17:06:57
function rp_recentlinks_month($limit = '',
                                $show_link_count = false,
                                $use_permalink = false,
                                $permalink_beginning = true,
                                $permalink_icon = '#',
                                $inline_caption = false,
                                $date_append = 'F j',
                                $before = '<li>',
                                $after = '</li>',
                                $between = "\n")
{
    global $table_prefix, $wpdb;
    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('gmt_offset');

    $y = strip_tags($_REQUEST['y']);
    $m = strip_tags($_REQUEST['m']);

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = gmdate('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $links = $wpdb->get_results("SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' AND YEAR(date_added) = '$y' AND MONTH(date_added) = '$m' ORDER BY date_added DESC" . $limit);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }
            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }

            // ID for permalinks
            $id = ' id="rlink-'.$link->ID.'"';


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&amp;')  &&  !strpos($link->link_url, '&#038;')  ) {
                $link->link_url = str_replace('&', '&amp;', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&amp;m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }


                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }

            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_archives()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the monthly archives for the recent links plugin.

$limit
    The number of links to display.
    Defaults to '', which shows all.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
function rp_recentlinks_archives($limit = '',
                                    $show_link_count = false,
                                    $before = '<li>',
                                    $after = '</li>',
                                    $between = "\n")
{
    global $table_prefix, $wpdb;
    $siteurl = get_settings('siteurl');
    $tablerecentlinks = $table_prefix.'recentlinks';
    $time_difference = get_settings('gmt_offset');

    $rewrite = get_settings('permalink_structure');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = gmdate('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(date_added) AS `year`, MONTH(date_added) AS `month`, count(ID) as links, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' GROUP BY YEAR(date_added), MONTH(date_added) ORDER BY date_added DESC" . $limit);

    if ($arcresults) {
        $out = '';
        foreach ($arcresults as $month) {
            if (strlen($rewrite) > 0) {
                $url = $siteurl.'/recent-links/'.date('Y/m/', strtotime($month->date_added));
            } else {
                $url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($month->date_added)).'&amp;m='.date('m', strtotime($month->date_added));
            }

            if ($show_link_count) {
                $link_count = ' ('.$month->links.')';
            } else {
                $link_count = '';
            }

            $link = '<a href="'.$url.'" title="'.date('F Y', strtotime($month->date_added)).'">'.date('F Y', strtotime($month->date_added)).'</a>'. $link_count;

            $out .= $before.$link.$after.$between;
        }

    }
    echo $out;
}








/* =========================================================================
                                               +++++++++++++++++++++++++++++
                                               ++  rp_recentlinks_home()  ++
                                               +++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays links for the home page.

$default_days
    The number of days of links to display.
    Defaults to 7.

========================================================================= */
function rp_recentlinks_home($default_days = 7)
{
    return rp_recentlinks_archive_page($default_days);
}





/* =========================================================================
                                       +++++++++++++++++++++++++++++++++++++
                                       ++  rp_recentlinks_archive_page()  ++
                                       +++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays links for the archive page (or current month).

$default_days
    The number of days of links to display.
    Defaults to 30.

========================================================================= */
function rp_recentlinks_archive_page($default_days = 30)
{
    global $table_prefix, $wpdb, $rp_recentlinks_vars;

    $y = '';
    $m = '';
    $d = '';

    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';


// begin## changes by Arthur Hoogervorst, thanks man.
//    if (strlen(get_settings('permalink_structure')) > 0) {
//        $y = strval($_GET['y']);
//        $m = strval($_GET['m']);
//    } else {
//        $y = strval(substr($_GET['m'], 0, 4));
//        if (strlen($_GET['m']) > 4) {
//            $m = strval(substr($_GET['m'], 4, 2));
//        }
//    }
    $y = strval($rp_recentlinks_vars['get']['y']);
    $m = strval($rp_recentlinks_vars['get']['m']);
// end##

    if (  strlen($y) == 4 && strlen($m) != 2 ) { //year
        $now       = $y.'-12-31 23:59:59';
        $last_day  = $y.'-01-01 00:00:00';
    } elseif (  strlen($y) == 4 && strlen($m) == 2 ) { //month
        if ( checkdate($m, '31', $y) ) {
            $now        = $y.'-'.$m.'-31 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '30', $y) ) {
            $now        = $y.'-'.$m.'-30 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '29', $y) ) {
            $now        = $y.'-'.$m.'-29 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } else {
            $now        = $y.'-'.$m.'-28 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        }
    } else {
        $now = gmdate('Y-m-d H:i:s',(time() + (get_settings('gmt_offset') * 3600)));
        $last_day = gmdate('Y-m-d H:i:s',((time()-(3600*24*$default_days)) + (get_settings('gmt_offset') * 3600))); // last 30 days of links
    }


    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND date_added > '$last_day' AND link_visible = 'Y' ORDER BY date_added DESC";

    $links = $wpdb->get_results($sql);

    if ($links) {

        for ($i=0; $i < count($links); $i++) {
            $links[$i]->link_text = stripslashes($links[$i]->link_text);
            $links[$i]->link_url = stripslashes($links[$i]->link_url);
            $links[$i]->link_caption = stripslashes($links[$i]->link_caption);
            $links[$i]->link_rel = stripslashes($links[$i]->link_rel);
            $links[$i]->link_target = stripslashes($links[$i]->link_target);

            if (strlen(get_settings('permalink_structure')) > 0) { // using mod_rewrite
                $links[$i]->link_permalink = get_settings('siteurl').'/recent-links/'.date('Y/m', strtotime($links[$i]->date_added)).'/#rlink-'.$links[$i]->ID;
            } else {
                $links[$i]->link_permalink = get_settings('siteurl').'/wp-recent-links.php?y='.date('Y', strtotime($links[$i]->date_added)).'&m='.date('m', strtotime($links[$i]->date_added)).'#rlink-'.$links[$i]->ID;
            }

            if (  is_int(strpos($links[$i]->link_url, '&'))  &&  !strpos($links[$i]->link_url, '&')  &&  !strpos($links[$i]->link_url, '&')  ) {
                $links[$i]->link_url = str_replace('&', '&', $links[$i]->link_url);
            }

            $links[$i]->link_text = strip_tags($links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag, '', $links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag2, '', $links[$i]->link_text);

        }
    }

    return $links;
}






/* =========================================================================
                                     +++++++++++++++++++++++++++++++++++++++
                                     ++  rp_recentlinks_archive_header()  ++
                                     +++++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays header for the archive page.

$links_name
    The name of the links section/header.
    Defaults to 'Recent Links'.

$date_format
    The date format of the links section/header, if date info is given.
    Based on PHP's date() function.
    Defaults to 'F Y' which is similar to 'March 2005'.

$separator
    The separator for the section name and date.
    Defaults to ' &#8250; ' which is similar to ' > '.

========================================================================= */
function rp_recentlinks_archive_header($links_name = 'Recent Links',
                                        $date_format = 'F Y',
                                        $separator = ' &raquo; ')
{
    global $rp_recentlinks_title, $rp_recentlinks_vars;

    if (  isset($rp_recentlinks_vars['get']['y'])
        && isset($rp_recentlinks_vars['get']['m'])
        && strlen(trim($rp_recentlinks_vars['get']['y'])) > 0
        && strlen(trim($rp_recentlinks_vars['get']['m'])) > 0
        ) {
        $rp_recentlinks_title = $links_name.$separator.date($date_format, strtotime($rp_recentlinks_vars['get']['y'].'-'.$rp_recentlinks_vars['get']['m'].'-01 01:01:01'));
    } else {
        $rp_recentlinks_title = $links_name;
    }
    echo $rp_recentlinks_title;
}


function rp_recentlinks_get_vars()
{
    global $rp_recentlinks_vars;

    $rp_recentlinks_vars['get'] = $_GET;
}


function rp_recentlinks_wp_title($text)
{
    global $rp_recentlinks_used;

    if ($rp_recentlinks_used) {
        ob_start();
        rp_recentlinks_archive_header();
        $out = ob_get_clean();
        return '  &raquo; '.$out;
    } else {
        return $text;
    }
}




// deprecated as of v2.04
function rp_recentlinks_begin_change_title()
{
    ob_start();
}

// deprecated as of v2.04
function rp_recentlinks_end_change_title()
{
    global $rp_new_title;
    $bef = ob_get_clean();
    $pattern = '#(<title[^>]*?'.'>)(.*?)(</title>)#si';
    $rp_new_title = get_option('blogname').' &raquo; '.$rp_new_title;
    echo  preg_replace($pattern, "<title>$rp_new_title</title>", $bef);
}





function rp_recentlinks_inline()
{
    global $posts;

    return rp_recentlinks_inline_merge(count($posts));
}





function rp_recentlinks_inline_css()
{

$css = <<<TEXT

<!-- css block for wp-recent-links -->
<style type="text/css" media="screen">
<!--
.recentlinks-inline {
    list-style:none;
    margin:2em 1em;
    font-size:0.8em;
}

.recentlinks-inline li {
    margin-bottom:1em;
}

-->
</style>

TEXT;

    echo $css;
}










/* undocumented yet, internal use only! */
function rp_recentlinks_inline_merge($entries = 7, $use_days = false, $cat_id = 0)
{
    global $table_prefix, $wpdb, $posts, $tablepost2cat, $rp_recentlinks_vars;

    if (  is_category()
            || is_page()
            || is_search()
        ) {
        return;
    }


    // cat_id hack, if using asides
    $cat_id = intval($cat_id);
    if ($cat_id > 0) {
        $sql = " SELECT post_id "
                ." FROM $tablepost2cat "
                ." WHERE category_id='$cat_id' "
                ." ORDER BY post_id ";
        $cat = $wpdb->get_results($sql);

        $cat_arr = array();
        foreach ($cat as $c) {
            $cat_arr[] = $c->post_id;
        }

    }
    // end hack




    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';


    if ($use_days) {
        $__p = array();
        $i = 0;
        $day_counter = 0;
        $__prev_date = '';

        foreach ($posts as $post) {
            if ($i == 0) {
                $__p[] = $post;
                $__prev_date = $post->post_date;
                $day_counter++;
            } else {
                if (date('Y-m-d', strtotime($post->post_date)) == date('Y-m-d', strtotime($__prev_date))) {
                    $__p[] = $post;
                } else {
                    $__p[] = $post;
                    // asides hack
                    if ($cat_id == 0) {
                        $day_counter++;
                    } else {
                        if ($cat_id > 0 && !in_array($post->ID, $cat_arr)) {
                            $day_counter++;
                        }
                    }
                    // end asides hack
                }
                $__prev_date = $post->post_date;
            }
            if ($day_counter == $entries) {
                break;
            }
            $i++;
        }
        $posts = $__p;

    } else {
        if (count($posts) > $entries) {
            $posts = array_slice($posts, 0, $entries);
        }
    }


// removed, replaced with new method of setting $y, $m, $d
//    if (strlen(get_settings('permalink_structure')) > 0) {
//        $y = strval($rp_recentlinks_vars['get']['year']);
//        $m = strval($rp_recentlinks_vars['get']['monthnum']);
//        $d = strval($rp_recentlinks_vars['get']['day']);
//        //$y = strval($_GET['year']);
//        //$m = strval($_GET['monthnum']);
//        //$d = strval($_GET['day']);
//
//       /*  $y = $_GET['year'];
//        $m = $_GET['monthnum'];
//        $d = $_GET['day']; */
//
//
//    } else {
//        $y = strval(substr($rp_recentlinks_vars['get']['m'], 0, 4));
//        if (strlen($rp_recentlinks_vars['get']['m']) > 4) {
//            $m = strval(substr($rp_recentlinks_vars['get']['m'], 4, 2));
//        }
//        if (strlen($rp_recentlinks_vars['get']['m']) > 6) {
//            $d = strval(substr($rp_recentlinks_vars['get']['m'], 6, 2));
//        }
//    }
//
//    echo '<!-- $posts[0]->post_date= '.$posts[0]->post_date.' | '.$posts[0]->post_title.' -->';
//    //strtotime($posts[0]->post_date);
//    //$y = gmdate('Y-m-d H:i:s', strtotime($posts[0]->post_date));



    $y = '';
    $m = '';
    $d = '';

    // get y,m,d from wp itself, not $_GET
    // sounds stupid, but wp2 limits us to this
    if (is_year()) {
        $y = gmdate('Y', strtotime($posts[0]->post_date));
    }
    if (is_month()) {
        $y = gmdate('Y', strtotime($posts[0]->post_date));
        $m = gmdate('m', strtotime($posts[0]->post_date));
    }
    if (is_day()) {
        $y = gmdate('Y', strtotime($posts[0]->post_date));
        $m = gmdate('m', strtotime($posts[0]->post_date));
        $d = gmdate('d', strtotime($posts[0]->post_date));
    }


    if (  strlen($y) == 4 && strlen($m) != 2 && strlen($d) != 2  ) {
        // year
        $now       = $y.'-12-31 23:59:59';
        $last_day  = $y.'-01-01 00:00:00';
    } elseif (  strlen($y) == 4 && strlen($m) == 2 && strlen($d) != 2  ) {
        if ( checkdate($m, '31', $y) ) {
            // month, 31 days
            $now        = $y.'-'.$m.'-31 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '30', $y) ) {
            // month, 30 days
            $now        = $y.'-'.$m.'-30 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '29', $y) ) {
            // month, 29 days
            $now        = $y.'-'.$m.'-29 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } else {
            // month, 28 days
            $now        = $y.'-'.$m.'-28 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        }
    } elseif (  strlen($y) == 4 && strlen($m) == 2 && strlen($d) == 2  ) {
        // date
        $now        = $y.'-'.$m.'-'.$d.' 23:59:59';
        $last_day   = $y.'-'.$m.'-'.$d.' 00:00:00';
    } elseif (  is_paged()  )  {
        // paged
        // for paged view, excess links should be at the top of next page
        // $now = should be equal to last entry of previous page

        $newer_date = _rp_next_newer_post($posts[0]->post_date);
        $now = gmdate('Y-m-d H:i:s', strtotime($newer_date));
        $last_day = gmdate('Y-m-d H:i:s', strtotime($posts[count($posts)-1]->post_date));
    } else {
        // index
        // $last_day - maybe remove 00:00:00 ???
        $now = gmdate('Y-m-d H:i:s',(time() + (get_settings('gmt_offset') * 3600)));
        $last_day = gmdate('Y-m-d', strtotime($posts[count($posts)-1]->post_date)).' 00:00:00';
    }


    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND date_added > '$last_day' AND link_visible = 'Y' ORDER BY date_added DESC";


    $links = $wpdb->get_results($sql);



    if ($links) {

        for ($i=0; $i < count($links); $i++) {
            $links[$i]->link_text = stripslashes($links[$i]->link_text);
            $links[$i]->link_url = stripslashes($links[$i]->link_url);
            $links[$i]->link_caption = stripslashes($links[$i]->link_caption);
            $links[$i]->link_rel = stripslashes($links[$i]->link_rel);
            $links[$i]->link_target = stripslashes($links[$i]->link_target);

            if (strlen(get_settings('permalink_structure')) > 0) { // using mod_rewrite
                $links[$i]->link_permalink = get_settings('siteurl').'/recent-links/'.date('Y/m', strtotime($links[$i]->date_added)).'/#rlink-'.$links[$i]->ID;
            } else {
                $links[$i]->link_permalink = get_settings('siteurl').'/wp-recent-links.php?y='.date('Y', strtotime($links[$i]->date_added)).'&amp;m='.date('m', strtotime($links[$i]->date_added)).'#rlink-'.$links[$i]->ID;
            }

            if (  is_int(strpos($links[$i]->link_url, '&'))  &&  !strpos($links[$i]->link_url, '&amp;')  &&  !strpos($links[$i]->link_url, '&#038;')  ) {
                $links[$i]->link_url = str_replace('&', '&amp;', $links[$i]->link_url);
            }

            $links[$i]->link_text = strip_tags($links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag, '', $links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag2, '', $links[$i]->link_text);

        }
    }

    $_tmp_arr = array();

    if (count($links) > 0) {
        $posts = array_merge($links, $posts);
    }

    foreach ($posts as $post) {
        $_tmp_item = array();
        if (isset($post->post_date_gmt)) {
            //$_tmp_item['0000_sort'] = $post->post_date_gmt;
            $_tmp_item['0000_sort'] = $post->post_date;
            $_tmp_item['post_object'] = $post;
            $_tmp_item['rp_entry_type'] = 'entry';
        } elseif (isset($post->date_added)) {
            //$_tmp_item['0000_sort'] = date('Y-m-d H:i:s', (strtotime($post->date_added) - (get_settings('gmt_offset') * 3600)));
            $_tmp_item['0000_sort'] = $post->date_added;
            $_tmp_item['post_object'] = $post;
            $_tmp_item['rp_entry_type'] = 'link';
        }
        $_tmp_arr[] = $_tmp_item;
    }
    rsort($_tmp_arr);
    $posts = array();
    $i = 0;
    foreach ($_tmp_arr as $_tmp_item) {
        $posts[$i] = $_tmp_item['post_object'];
        $posts[$i]->rp_entry_type = $_tmp_item['rp_entry_type'];

        $i++;
    }

}



function rp_recentlinks_header200()
{
    global $rp_recentlinks_used;

    if ($rp_recentlinks_used) {
        if (!headers_sent()) { 
            if ( preg_match('/cgi/', php_sapi_name()) )
                @header('Status: 200 OK');
            else
                @header('HTTP/1.x 200 OK');
        } 
    }
}


function _rp_next_newer_post($date)
{
    global $wpdb;

    $sql = " SELECT post_date FROM $wpdb->posts "
            ." WHERE post_date > '$date' "
            ." AND post_status = 'publish' "
            ." ORDER BY post_date ASC "
            ." LIMIT 1 ";
    $newer_date = $wpdb->get_var($sql);

    return $newer_date;
}










function rp_recentlinks_install() {
   global $table_prefix, $wpdb, $user_level;

   $table_name = $table_prefix . 'recentlinks';

   get_currentuserinfo();
   if ($user_level < 8) { return; }

   if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {

        $now = gmdate('Y-m-d H:i:s', (time() + (get_settings('gmt_offset') * 3600)));
        $sql = "CREATE TABLE $table_name ( "
                             ."ID int(11) NOT NULL AUTO_INCREMENT, "
                             ."link_author int(11) NOT NULL default '0', "
                             ."date_added datetime NOT NULL default '0000-00-00 00:00:00', "
                             ."link_url varchar(255) NOT NULL, "
                             ."link_text varchar(255) NOT NULL, "
                             ."link_caption TEXT NOT NULL, "
                             ."link_rel varchar(255) NOT NULL, "
                             ."link_target varchar(100) NOT NULL, "
                             ."link_visible enum('Y', 'N') NOT NULL default 'Y', "
                             ."PRIMARY KEY (ID) "
                             .")";

          require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
          dbDelta($sql);


          $insert = "INSERT INTO $table_name SET link_author='1', date_added='$now', link_url='http://rebelpixel.com/', link_text='rebelpixel productions', link_caption='WordPress plugins. Weblog design. PHP development. Digital photography.'";
          $results = $wpdb->query( $insert );

          $insert = "INSERT INTO $table_name SET link_author='1', date_added='$now', link_url='http://isulongseoph.net/', link_text='Isulong SEOPH!', link_caption=''";
          $results = $wpdb->query( $insert );

          $insert = "INSERT INTO $table_name SET link_author='1', date_added='$now', link_url='http://lyrics.rebelpixel.com/', link_text='lyrics!', link_caption='<strong>lyrics!</strong> is a lyrics weblog for the Filipino people, also from <a href=\"http://rebelpixel.com/\">rebelpixel productions.</a>'";
          $results = $wpdb->query( $insert );

          $insert = "INSERT INTO $table_name SET link_author='1', date_added='$now', link_url='http://rebelpixel.com/projects/wp-recent-links/', link_text='This is wp-recent-links!', link_caption='<strong>wp-recent-links</strong> is a WordPress plugin for adding a links blog to your WordPress&#8211;powered site.'";
          $results = $wpdb->query( $insert );

   }

}





function rp_recentlinks_upgrade_table()
{
    global $table_prefix, $wpdb, $user_level;

    $table_name = $table_prefix . 'recentlinks';

    get_currentuserinfo();
    if ($user_level < 8) { return; }

    if ( get_option('rp_recentlinks_table_version') != '2.0' ) {
        $sql = "ALTER TABLE $table_name MODIFY link_caption TEXT NOT NULL";
        $wpdb->query($sql);
        update_option('rp_recentlinks_table_version', '2.0');
    }
}




function rp_recentlinks_rewrite($rules = '')
{
    if ($rules != '') {
        $added_rules = '### BEGIN wp-recent-links rules'."\n"
                        .'RewriteRule    ^recent-links/feed?/?$  wp-recent-links-rss2.php  [QSA]'."\n"
                        .'RewriteRule    ^recent-links?/?$  wp-recent-links.php  [QSA]'."\n"
                        .'RewriteRule    ^recent-links/([0-9]{4})?/?([0-9]{1,2})?/?$  wp-recent-links.php?y=$1&m=$2  [QSA]'."\n"
                        .'### END wp-recent-links rules'."\n";
        return $added_rules.$rules;
    } else {
        return $rules;
    }
}





if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
   add_action('init', 'rp_recentlinks_install');
   add_action('init', 'rp_recentlinks_upgrade_table');
}












//! *** CQS embedded
// we are embedding Matt Read's excellent CQS plugin to control our "query views"
// Thanks Matt.

if (!class_exists('cqs') && $rp_recentlinks_use_cqs) { //we don't want to fuck up real CQS rules
    

/* <WP plugin data>
 * Plugin Name:   Custom Query String
 * Version:       2.6
 * Plugin URI:    http://mattread.com/projects/wp-plugins/custom-query-string-plugin/
 * Description:   Change the number of posts displayed when viewing an archive page.
 * Author:        Matt Read
 * Author URI:    http://www.mattread.com/
 *
 * License:       GNU General Public License
 *
 * 
 * Copyright (C) 2005  Matt Read
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 * You can contact the author by the following:
 * Matt Read
 * 102 Delaney Drive
 * Ottawa, ON K0A 1L0 CA
 * mattread@mattread.com
 */

# define the current verion
//define('k_CQS_VER', '2.6');

//class cqs
class rp_cqs
{
	var $query = false;
	var $category = false;
	var $query_vars = array();
	var $query_string;
	var $options = array();
	var $option = array();
	var $what_to_shows = array('posts', 'days');
	var $conditions = array('is_archive', 'is_author', 'is_category', 'is_date', 'is_year', 'is_month', 'is_day', 'is_time', 'is_search', 'is_home', 'is_paged', 'is_feed');
	var $orderbys = array('date','category','title','author');
	var $orders = array('DESC', 'ASC');
	var $request = array();

	
	/**
	 * Register WordPress plugin actions.
	 * @since version 2.6
	 */
	function rp_cqs() {
		//add_action('activate_'.basename(__FILE__), array(&$this, 'activate'));
		//add_action('deactivate_'.basename(__FILE__), array(&$this, 'deactivate'));
		//add_action('admin_menu', array(&$this, 'admin_menu'));
		add_filter('query_string', array(&$this, 'custom_query_string'));
	}
	
	
	/**
	 * Initializes the variables etc..
	 * @param string  the query string to be modified.
	 * @since version 2.0.1
	 */
	function init($query_string) {
		parse_str($query_string, $qv);
		$this->query_string = $query_string;
		$this->query_vars = $qv;

        //options hack by markku for wp-recent-links
        $opt['is_month']['posts_per_page'] = 31;
        $opt['is_month']['what_to_show'] = 'days';
        $opt['is_month']['orderby'] = 'date';
        $opt['is_month']['order'] = 'DESC';
        $opt['is_year']['posts_per_page'] = 366;
        $opt['is_year']['what_to_show'] = 'days';
        $opt['is_year']['orderby'] = 'date';
        $opt['is_year']['order'] = 'DESC';

		//$this->options = get_option('cqs_options');
		$this->options = $opt;
		if ($this->options) {
			$this->get_query();
			/* $this->get_category(); we don't need this --markku */
		}
	}
	
	
	/**
	 * The main function, merges query string with our new queries
	 * @param string  the query string to be modified.
	 * @since version 2.0
	 * @return string  the new customized query string.
	 * @access public
	 */
	function custom_query_string($query_string) {
		$this->init($query_string);
	
		/*
		 * Check if have a custom query for this category then check
		 * if have a custom query and only add it if it exsists.
		 */
		if ( $this->category )
			$this->option = $this->options[$this->category];
		elseif ( $this->query )
			$this->option = $this->options[$this->query];

		if ( $this->option ) {
			$custom_query_string = array(
				'posts_per_page' => $this->option['posts_per_page'],
				'what_to_show' => $this->option['what_to_show'],
				'orderby' => $this->option['orderby'],
				'order' => $this->option['order']
				);
			/*
			 * Make sure we don't override any queries already set.  Merge
			 * the original query vars to the new ones.  Then build the string
			 * from the new array.
			 */
			$this->query_vars = array_merge($custom_query_string,$this->query_vars);
			$this->query_string = $this->build_query_string($this->query_vars);
		}
		return $this->query_string;
	}


	/**
	 * Rebuild query string from assosiative array
	 * @since version 2.0
	 */
	function build_query_string ($query_vars) {
		foreach ($query_vars as $key => $value) {
			$query[] = $key.'='.$value;
		}
		return join('&', $query);
	}


	/**
	 * Determines the type of query to use
	 * the order is very important!
	 * archive includes: author, category and date.
	 * date includes: time, day, month, year.
	 * paged overrides all. Use with caution!
	 * @since version 2.0
	 */
	function get_query() {
		global $wp_query;
		$wp_query->parse_query($this->query_string);

		if ($wp_query->is_feed AND $this->options['is_feed'])
			$this->query = 'is_feed';

		elseif ($wp_query->is_paged AND $this->options['is_paged'])
			$this->query = 'is_paged';

		elseif ($wp_query->is_archive)
		{
			if ($wp_query->is_author AND $this->options['is_author'])
				$this->query = 'is_author';

			elseif ($wp_query->is_category AND $this->options['is_category'])
				$this->query = 'is_category';
			
			elseif ($wp_query->is_date)
			{
				if ($wp_query->is_time AND $this->options['is_time'])
					$this->query = 'is_time';
				
				elseif ($wp_query->is_day AND $this->options['is_day'])
					$this->query = 'is_day';
				
				elseif ($wp_query->is_month AND $this->options['is_month'])
					$this->query = 'is_month';
				
				elseif ($wp_query->is_year AND $this->options['is_year'])
					$this->query = 'is_year';
				
				elseif ($this->options['is_date'])
					$this->query = 'is_date';
			}
			elseif ($this->options['is_archive'])
				$this->query = 'is_archive';
		}
		elseif ($wp_query->is_search AND $this->options['is_search'])
			$this->query = 'is_search';

		elseif ($wp_query->is_home AND $this->options['is_home'])
			$this->query = 'is_home';
	}


}

$rp_cqs = new rp_cqs();

} // class_exists

















// -------------------------------------------------------------------------
//! Older functions, deprecated. Please try not to use!
// These are aliases for old functions (my-hacks.php days!)
// -------------------------------------------------------------------------

function rpmod_recentlinks($limit = 12, $before = '<li>', $after = '</li>', $between = "\n", $date_append = 'F j')
{
    return rp_recentlinks($limit, false, false, '', false, $date_append, $before, $after, $between);
}

function rpmod_recentlinks_archives_url()
{
    return rp_recentlinks_archives_url();
}

function rpmod_recentlinks_rss2_url()
{
    return rp_recentlinks_rss2_url();
}

function rpmod_recentlinks_month($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_month($limit, false, false, true, '#', false, 'F j', $before, $after, $between);
}

function rpmod_recentlinks_archives($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_archives($limit, $show_link_count, $before, $after, $between);
}





/**************----------------  STANDALONE SECTION  ---------------**************/
// Thanks to Kitten's Spaminator I can now write a WP-1.5 plugin! :)


if (function_exists('is_plugin_page') && is_plugin_page()) { ?>
    <div class="wrap">
    <h2>Recent Links</h2>
    <p>A linklog plugin for WordPress, allowing you to have your own blog of
    links without the need for another wp-powered weblog or (gasp!) another
    weblog software. More information at the
    <a href="http://rebelpixel.com/projects/wp-recent-links/">project's page</a>.
    </p>
    </div>
<?php }
else {
    function rp_recentlinks_admin_menu() {
        add_submenu_page('post.php', 'Add Recent Link', 'Add Recent Link', 5, 'recent-links.php'); // adds to the Write menu
        add_management_page('Recent Links', 'Recent Links', 5, 'recent-links.php'); // adds to the Manage menu
    }
}
add_action('init', 'rp_recentlinks_get_vars');
add_action('admin_menu', 'rp_recentlinks_admin_menu'); // runs the function to add those menus
add_action('wp_head', 'rp_recentlinks_inline_css');
add_filter('mod_rewrite_rules', 'rp_recentlinks_rewrite');
add_filter('wp_title', 'rp_recentlinks_wp_title');

/**************--------------  END STANDALONE SECTION  -------------**************/
?>